==> kitten-components-20.17.0.tgz: package/assets/javascripts/kitten/components/buttons/social-button-icon-words.test.js <==
import React from 'react'
import {
  FacebookButtonIconWords,
  TwitterButtonIconWords,
  LinkedinButtonIconWords,
} from 'kitten/components/buttons/social-button-icon-words'
import { Button } from 'kitten/components/buttons/button'
import { FacebookIcon } from 'kitten/components/icons/facebook-icon'
import { TwitterIcon } from 'kitten/components/icons/twitter-icon'
import { LinkedinIcon } from 'kitten/components/icons/linkedin-icon'

describe('<FacebookButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<FacebookButtonIconWords />)

    it('is a <Button modifier="facebook" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('facebook')
    })

    it('has a <FacebookIcon />', () => {
      expect(button.find(FacebookIcon).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <FacebookButtonIconWords>Lorem ipsum…</FacebookButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})

describe('<TwitterButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<TwitterButtonIconWords />)

    it('is a <Button modifier="twitter" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('twitter')
    })

    it('has a <TwitterIcon />', () => {
      expect(button.find(TwitterIcon).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <TwitterButtonIconWords>Lorem ipsum…</TwitterButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})

describe('<LinkedinButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<LinkedinButtonIconWords />)

    it('is a <Button modifier="linkedin" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('linkedin')
    })

    it('has a <LinkedinIcon />', () => {
      expect(button.find(LinkedinIcon).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <LinkedinButtonIconWords>Lorem ipsum…</LinkedinButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})

==> kitten-components-23.3.0.tgz: package/assets/javascripts/kitten/components/buttons/social-button-icon-words.test.js <==
import React from 'react'
import {
  FacebookButtonIconWords,
  TwitterButtonIconWords,
  LinkedinButtonIconWords,
} from 'kitten/components/buttons/social-button-icon-words'
import { Button } from 'kitten/components/buttons/button'
import { FacebookIconWithBackground } from 'kitten/components/icons/facebook-icon-with-background'
import { TwitterIcon } from 'kitten/components/icons/twitter-icon'
import { LinkedinIcon } from 'kitten/components/icons/linkedin-icon'

describe('<FacebookButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<FacebookButtonIconWords />)

    it('is a <Button modifier="facebook" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('facebook')
    })

    it('has a <FacebookIconWithBackground />', () => {
      expect(button.find(FacebookIconWithBackground).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <FacebookButtonIconWords>Lorem ipsum…</FacebookButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})

describe('<TwitterButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<TwitterButtonIconWords />)

    it('is a <Button modifier="twitter" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('twitter')
    })

    it('has a <TwitterIcon />', () => {
      expect(button.find(TwitterIcon).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <TwitterButtonIconWords>Lorem ipsum…</TwitterButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})

describe('<LinkedinButtonIconWords />', () => {
  describe('by default', () => {
    const button = shallow(<LinkedinButtonIconWords />)

    it('is a <Button modifier="linkedin" />', () => {
      expect(button.find(Button).exists()).toBe(true)
      expect(button.props().modifier).toBe('linkedin')
    })

    it('has a <LinkedinIcon />', () => {
      expect(button.find(LinkedinIcon).exists()).toBe(true)
    })
  })

  describe('children prop', () => {
    const component = mount(
      <LinkedinButtonIconWords>Lorem ipsum…</LinkedinButtonIconWords>,
    )

    it('renders the right children', () => {
      expect(component.props().children).toEqual('Lorem ipsum…')
    })
  })
})
